IOHttpTransport class final

A transport over dart:io, and the handle that closes it.

Implemented types

Constructors

IOHttpTransport({Duration connectTimeout = const Duration(seconds: 10), Duration timeout = const Duration(seconds: 30)})
Builds a transport with the given timeouts.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Releases the underlying connections. Safe to call more than once.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(HttpRequest request) Future<HttpResponse>
Sends request.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited